@@ -117,9 +117,12 @@ class Session:
         )
         async with aiohttp.ClientSession(
             connector=conn,
-            headers={'User-Agent': f'stpmex-python/{client_version}'},
+            headers={
+                'User-Agent': f'stpmex-python/{client_version}',
+                'content-type': 'text/xml',
+            },
         ) as session:
-            async with session.request(method, url, json=data) as response:
+            async with session.request(method, url, data=data) as response:
                 if response.status != 200:
                     response.raise_for_status()
                 resultado = await response.text()
